#!/usr/bin/python3.9
# -*- coding: utf-8 -*-
# @Time    :  2023/7/18 14:54
# @Author  : chenxw
# @Email   : gisfanmachel@gmail.com
# @File    : mathTools.py
# @Descr   : 
# @Software: PyCharm
import re


class MathHelper:
    def __int__(self):
        pass
 # 乘除
    @staticmethod
    def __mu_di(formula):
        if "*" in formula:
            a, b = formula.split("*")
            a = float(a)
            b = float(b)
            formula = float(a) * float(b)
            return formula
        if "/" in formula:
            a, b = formula.split("/")
            a = float(a)
            b = float(b)
            formula = float(a) / float(b)
            return formula
        else:
            print("乘除函数符号错误")

    # 加减
    @staticmethod
    def __add_Sub(num):
        lst_num = re.findall("[-+]?[0-9]+\.?[0-9]*", num)
        ##匹配数字可以包含或不包含小数点后面和前面的正负数
        count = 0
        for i in lst_num:
            count += float(i)
        return count

    ##去符号
    @staticmethod
    def __degbug(num):
        num = num.replace("--", "+")
        num = num.replace("-+", "-")
        num = num.replace("++", "+")
        num = num.replace("+-", "-")
        return num

    # 计算
    @staticmethod
    def __calculate(formula):
        # formula = str(formula)
        # print(type(formula))
        while True:
            tmp = re.search("[0-9]+\.?[0-9]*[*/][+-]?[0-9]+\.?[0-9]*", formula)  ###找出第一个乘除，后面循环全部替换为浮点数
            if tmp:
                tmp = tmp.group()
                tmp2 = str(MathHelper.__mu_di(tmp))
                formula = formula.replace(tmp, tmp2)
                # tmp = re.search("[0-9]+\.?[0-9]*[*/][+-]?[0-9]+\.?[0-9]*",formula).group()
            else:
                break
        formula1 = MathHelper.__degbug(formula)
        formula2 = MathHelper.__add_Sub(formula1)
        return formula2

    # 括号内计算
    @staticmethod
    def __No_brackets(formula):
        while True:
            innum = re.search(r'\([^()]+\)', formula)
            ###匹配第一个没有内部括号的括号内函数，后面循环全部替换为浮点数
            if innum:
                tmp = innum.group()
                tmp2 = MathHelper.__calculate(tmp)
                formula = formula.replace(tmp, str(tmp2))
            else:
                break
        return formula

    # 解析自然表达式里的公式并进行计算出结果
    @staticmethod
    def exp_mian(formula):
        print("计算表达式为：{}".format(formula))
        formula = formula.replace(" ", "")
        formula_tmp1 = MathHelper.__No_brackets(formula)
        result_exp = MathHelper.__calculate(formula_tmp1)
        return result_exp

if __name__ == '__main__':
    hanshu = " 1 - 2 *  (60-30 +(-40/5) * (9-2*5/3 + 7 /3*99/4*2998 +10 * 568/14 ))"
    s1 = MathHelper.exp_mian(hanshu)
    print(s1)

    hanshu = " 1 - 0.4 * (1-0.8)+0.8*0.2"
    s1 = MathHelper.exp_mian(hanshu)
    print(s1)

    hanshu = "0.8*(1 - 0.4)+0.1*(1-0.5)+0.1*0.56"
    s1 = MathHelper.exp_mian(hanshu)
    print(s1)

    hanshu = "0.8(1 - 0.4)"
    s1 = MathHelper.exp_mian(hanshu)
    print(s1)

    hanshu = "0.8*(1 - 0.4)"
    s1 = MathHelper.exp_mian(hanshu)
    print(s1)



#!/usr/bin/python3.9
# -*- coding: utf-8 -*-
# @Time    :  2023/6/27 14:20
# @Author  : chenxw
# @Email   : gisfanmachel@gmail.com
# @File    : listTools.py
# @Descr   : 
# @Software: PyCharm
from operator import itemgetter


class ListHelper:
    def __int__(self):
        pass

    # ------------------------------------
    # list数组的操作
    # ------------------------------------
    @staticmethod
    # list数组去重
    def remove_same_item(ids):
        news_ids = []
        for id in ids:
            if id not in news_ids:
                news_ids.append(id)
        return news_ids

    @staticmethod
    # 去掉list数组中重复项
    def remove_same_element_of_list(ele_list):
        new_ele_list = []
        for ele in ele_list:
            if ele not in new_ele_list:
                new_ele_list.append(ele)
        return new_ele_list

    @staticmethod
    # 去掉list数组中空白项
    def remove_blank_elment_of_list(ele_list):
        new_ele_list = []
        for ele in ele_list:
            if str(str(ele).strip()) != "":
                new_ele_list.append(ele)
        return new_ele_list

    @staticmethod
    # 查找元素在list数组中的索引号
    def get_index_in_list_of_elment(element, ele_list):
        # index = ele_list.index(element)
        return_index = -1
        for index in range(len(ele_list)):
            if ele_list[index] == element:
                return_index = index
                break
        return return_index

    @staticmethod
    # 获取元素在list数组中出现的次数
    def get_value_count_in_list(value, value_list):
        count = 0
        for tempvalue in value_list:
            if value == tempvalue:
                count = count + 1
        return count

    @staticmethod
    # 将所有list数组合并成一个list数组
    def convert_all_list_into_one_list(all_data_record_list):
        result_data_list = []
        for each_data_record_list in all_data_record_list:
            for data_field_value_obj in each_data_record_list:
                result_data_list.append(data_field_value_obj)
        return result_data_list

    # 将list数组里的数字用逗号拼接成字符串
    @staticmethod
    def get_number_str_by_list(num_list):
        number_str = ""
        for num in num_list:
            number_str = number_str + str(num) + ","
        number_str = number_str.rstrip(",")
        return number_str

    # 将list数组转换为指定字符连接的字符串
    @staticmethod
    def get_connect_str_by_list(connector_char, list_obj):
        return connector_char.join(str(x) for x in list_obj)


    # ---------------------------------------
    # dict字典的操作
    # ---------------------------------------

    @staticmethod
    # 根据字段名称获取dict对象里的字段索引
    def get_field_index_in_dict(dict_obj, field_name):
        key_index = 0
        field_index = None
        for key in dict_obj:
            if key == field_name:
                field_index = key_index
                break
            key_index += 1
        return field_index

    @staticmethod
    # 根据字段索引获取dict对象里的字段名称
    def get_field_name_in_dict(dict_obj, field_index):
        field_name = None
        key_index = 0
        for key in dict_obj:
            if key_index == field_index:
                field_name = key
                break
            key_index += 1
        return field_name

    @staticmethod
    # 获取dict里包含的字段列
    def get_key_name_str(data_dict):
        columns = []
        for key, value in data_dict.items():
            columns.append(key)
        return columns

    @staticmethod
    # 删除dict对象里不要的key
    def remove_keys_in_obj(obj, remove_key_list):
        for remove_key in remove_key_list:
            if remove_key in obj:
                del obj[remove_key]

    @staticmethod
    # 对dict里的字典内容进行排序
    def sort_dict_by_filed(item_list, sort_field):
        return sorted(item_list, key=itemgetter(sort_field))

    @staticmethod
    # 判断dict字典是否有搜索对象
    def is_has_item_in_dict(search_item_value, item_list):
        is_find = False
        for item_name in item_list:
            if item_name == search_item_value:
                is_find = True
                break
        return is_find



# -*- coding:utf-8 -*-

import base64
import os

import cv2
import numpy as np
from PIL import Image
from PIL import ImageDraw


class ImageHelper:
    def __init__(self):
        pass

    # 获取图片的base64码,有点问题
    @staticmethod
    def convert2Base64(image_path):
        icon = open(image_path, 'rb')
        iconData = icon.read()
        iconData = base64.b64encode(iconData)
        LIMIT = 60
        liIcon = []
        while True:
            sLimit = iconData[:LIMIT]
            iconData = iconData[LIMIT:]
            liIcon.append('\'%s\'' % sLimit)
            if len(sLimit) < LIMIT:
                break
        base64_img_str = os.linesep.join(liIcon)
        return base64_img_str

    # 根据指定范围生成二值图
    @staticmethod
    def build_binary_image(input_pic_file_path, result_pic_file_path, white_region_array):
        # 生成黑色图片
        old_img = Image.open(input_pic_file_path)
        height = old_img.height
        width = old_img.width
        black_img = Image.new("RGB", (width, height))
        # 对指定区域进行白色填充
        for region in white_region_array:
            # region为x1,y1,x2,y2...xn,yn
            draw = ImageDraw.Draw(black_img)
            draw.polygon(region, fill=(255, 255, 255, 255), outline=(255, 255, 255, 255))
        black_img.save(result_pic_file_path)

    # 获取目录下所有图片路径
    @staticmethod
    def get_image_list(image_dir,
                       suffix=['jpg', 'jpeg', 'JPG', 'JPEG', 'png', 'PNG', 'bmp', 'BMP', 'GIF', 'gif']):
        '''get all vgis_image path ends with suffix'''
        if not os.path.exists(image_dir):
            print("PATH:%s not exists" % image_dir)
            return []
        imglist = []
        for root, sdirs, files in os.walk(image_dir):
            if not files:
                continue
            for filename in files:
                filepath = os.path.join(root, filename)
                if filename.split('.')[-1] in suffix:
                    imglist.append(filepath)
        return imglist

    # 按照指定大小对图片大小进行重定义
    @staticmethod
    def resize_image_by_size(input_file_path, resize_width,resize_height,out_file_path):
        img = Image.open(input_file_path)
        new_img = img.resize((resize_width, resize_height), Image.BILINEAR)
        new_img.save(out_file_path)

    # 根据百分比缩放图片
    @staticmethod
    def resize_image_by_percent():
        pass

    # 对图像进行裁切，按照两条水平线
    @staticmethod
    def clip_image_by_line():
        pass

    @staticmethod
    def add_polygon_on_tif(tif_file):
        try:
            img = cv2.imread(tif_file, -1)
            # 输出图像信息
            # print(img)
            print(img.shape)
            print(img.dtype)
            print(img.min())
            print(img.max())
            # 读取数据，显示图像
            img = cv2.imread(tif_file, -1)
            # 将数据格式进行转换
            img = np.array(img)
            # 绘制多边形
            pts = np.array([[200, 100], [200, 300], [250, 300], [500, 200], [500, 40]], np.int32)  # 构建多边形的顶点
            cv2.polylines(img, [pts], True, (255, 0, 0), 3)

            # 设置图像窗口
            cv2.namedWindow(tif_file, 1)  # 第一个参数设置窗口名字，第二个参数"1"为根据电脑显示器自动调整窗口大小
            cv2.imshow(tif_file, img)  # 显示图像

            # 设置等待时间为0毫秒（参数0表示等待时间为无限）
            cv2.waitKey(0)

            # 释放窗口
            cv2.destroyAllWindows()
        except Exception as exp:
            print(exp)
            print(exp.__traceback__.tb_frame.f_globals["__file__"])  # 发生异常所在的文件
            print(exp.__traceback__.tb_lineno)  # 发生异常所在的行数



# AI样本二值图生成单元测试方法
def build_binary_image_test(image_operator):
    while_region_array = []
    while_region_array.append([11, 45, 34, 55, 67, 44, 14, 55])
    while_region_array.append([101, 450, 340, 550, 670, 440, 140, 550])
    image_operator.build_binary_image("d:\\airport.jpg", "d:\\airport_bin.jpg", while_region_array)


# # 主入口,进行测试
# if __name__ == '__main__':
#     try:
#         image_operator = ImageOperator()
#         build_binary_image_test(image_operator)
#     except Exception as tm_exp:
#         print("AI样本二值图生成失败：{}".format(str(tm_exp)))



"""
===================================
#!/usr/bin/python3.9
# -*- coding: utf-8 -*-
@Author: chenxw
@Email : gisfanmachel@gmail.com
@File: datetimeTools.py
@Date: Create in 2021/1/25 16:36
@Description: 
@ Software: PyCharm
===================================
"""
import datetime
import re
import time
from datetime import timedelta

# 需要引用最顶层的
from vgis_aiutils.commonTools import CommonHelper


class DateTimeHelper:
    def __init__(self):
        pass

    @staticmethod
    # 解析自然语言时间字符串为标准时间（YYYY-MM-DD HH:MM:SS）
    # 如39秒前
    # 1分钟前
    # 今天09:45
    # 01月24日 12:39-->2023--1-24 12:39:00
    # 2020年12月22日 20:31 -->2020-12-22 20:31:00
    # 2023-08-31T00:00:00 -->2023-08-0-31 00:00:00
    # 2023/7/31T17:55 --> 2023-07-31 17:55:00
    # 2023/7/31T17:55:23 -->2023-07-31 17:55:23
    # 2023-8-6 17:33:00 -->2023-08-06 17:33:00
    def get_standTime_By_Str(time_str):
        info_time = time_str
        current_year = str(datetime.datetime.now().year)
        current_month = str(datetime.datetime.now().month)
        current_day = str(datetime.datetime.now().day)
        current_hour = str(datetime.datetime.now().hour)
        current_minute = str(datetime.datetime.now().minute)
        current_second = str(datetime.datetime.now().second)
        info_time = info_time.strip()
        # 39秒前
        if "秒" in info_time:
            second_num = int(re.findall("\d+", info_time)[0])
            info_time = (datetime.datetime.now() - datetime.timedelta(seconds=second_num)).strftime("%Y-%m-%d %H:%M:%S")
        # 1分钟前
        if "分" in info_time:
            minute_num = int(re.findall("\d+", info_time)[0])
            info_time = (datetime.datetime.now() - datetime.timedelta(minutes=minute_num)).strftime("%Y-%m-%d %H:%M:%S")
        # 今天09:45
        if "今天" in info_time:
            info_time = info_time.replace("今天",
                                          current_year + "-" + current_month + "-" + current_day + " ")
            if info_time.count(":") == 1:
                info_time = info_time + ":00"
        # 01月24日 12:39
        if "年" not in info_time and "月" in info_time and "日" in info_time:
            info_time = current_year + "年" + info_time
            if info_time.count(":") == 1:
                info_time = info_time + ":00"
        # 2020年12月22日 20:31
        if "年" in info_time and "月" in info_time and "日" in info_time:
            if info_time.count(":") == 1:
                info_time = info_time + ":00"
        # 2023-08-31T00:00:00 -->2023-08-31 00:00:00
        if "T" in info_time:
            info_time = info_time.replace("T", " ")
        if "/" in info_time:
            info_time = info_time.replace("/", "-")
        if info_time.count(":") == 1:
            info_time = info_time + ":00"
        return info_time

    @staticmethod
    # 将秒数转换为*时*分*秒
    def convert_seconds(seconds):
        m, s = divmod(seconds, 60)
        h, m = divmod(m, 60)
        result = "{}秒".format(int(s))
        if m > 0:
            result = "{}分".format(int(m)) + result
        if h > 0:
            result = "{}时".format(int(m)) + result
        # print("程序总共耗时%02d:%02d:%02d" % (h, m, s))
        return result

    @staticmethod
    # 将识别字符如2月23日转换为2023-02-27,年份默认用当年
    # 2022年12月22日，需要翻译成2022-12-22
    # 05-May-23 翻译 2023-05-27
    def convert_date(recog_str):
        need_date = None
        try:
            # 先验证是否是日期类型
            if DateTimeHelper.is_date_str(recog_str):
                need_date = recog_str
            else:
                # 2月23日,增加当前年
                if "年" not in recog_str and "月" in recog_str and "日" in recog_str:
                    ret = re.findall(r'\s*(\d{1,2})\s*[\./月-]\s*(\d{1,2})\s*日?', recog_str)
                    if ret:
                        month, day = ret[0]
                        year = datetime.datetime.today().year
                        need_date = str(year) + "-" + str(month) + "-" + str(day)
                # 2022年12月22日
                if "年" in recog_str and "月" in recog_str and "日" in recog_str:
                    ret = re.findall(r'(\d{4})\s*[\./年-]\s*(\d{1,2})\s*[\./月-]\s*(\d{1,2})\s*日?', recog_str)
                    if ret:
                        year, month, day = ret[0]
                        need_date = str(year) + "-" + str(month) + "-" + str(day)
                # 05-May-23
                if CommonHelper.is_has_en_month(recog_str):
                    month_str = re.sub("[\u4e00-\u9fa5\0-9\,\。]", "", recog_str)
                    month_num = DateTimeHelper.convert_month_from_en_to_num(month_str)
                    need_date_split = recog_str.split("-")
                    year = need_date_split[2]
                    if len(year) == 2:
                        year = "20" + year
                    need_date = year + "-" + month_num + "-" + need_date_split[0]

        except Exception as exp:
            print(exp)
            print(exp.__traceback__.tb_frame.f_globals["__file__"])  # 发生异常所在的文件
            print(exp.__traceback__.tb_lineno)  # 发生异常所在的行数
        finally:
            # print(need_date)
            return need_date

    @staticmethod
    # 判断日期里是否含有英文月份
    def is_has_en_month(date_str):
        is_find = False
        month_list = "January,Jan,JAN,February,Feb,FEB,March,Mar,MAR,April,Apr,APR,May,MAY,June,JUNE,Jun,JUN,July,Jul,JUL,August,Aug,AUG,September,Sep,SEP,October,Oct,OCT,November,Nov,NOV,December,Dec,DEC".split(
            ",")
        month_str = re.sub("[\u4e00-\u9fa5\0-9\,\。]", "", date_str)
        if month_str in month_list:
            is_find = True
        return is_find

    @staticmethod
    # 将月份从字母转为数字
    def convert_month_from_en_to_num(month_en):
        month_abbr_list = [
            'JAN',
            'FEB',
            'MAR',
            'APR',
            'MAY',
            'JUN',
            'JUL',
            'AUG',
            'SEP',
            'OCT',
            'NOV',
            'DEC']
        month_index = month_abbr_list.index(month_en.upper())
        month_num = month_index + 1
        if len(str(month_num)) == 1:
            month_num = "0" + str(month_num)
        return str(month_num)

    @staticmethod
    # 从日期中提取年月日
    # 输入2023年12月22日、12月22日、2023-12-22
    # 输出2023、12、22
    def parse_date(date_str):
        date_year = None
        date_month = None
        date_day = None
        try:
            date_str = DateTimeHelper.convert_date(date_str)
            date_year = date_str.split("-")[0]
            date_month = date_str.split("-")[1]
            date_day = date_str.split("-")[2]
        except Exception as exp:
            pass
            # logger.error(exp)
            # logger.error(exp.__traceback__.tb_frame.f_globals["__file__"])  # 发生异常所在的文件
            # logger.error(exp.__traceback__.tb_lineno)  # 发生异常所在的行数
        finally:
            # print(need_date)
            return date_year, date_month, date_day

    @staticmethod
    # 判断字符串是否为日期类型
    def is_date_str(date_text):
        is_date_type = True
        try:
            datetime.datetime.strptime(date_text, '%Y-%m-%d')
            is_date_type = True
        except ValueError:
            is_date_type = False
        if is_date_type is False:
            try:
                datetime.datetime.strptime(date_text, '%Y %m %d')
                is_date_type = True
            except ValueError:
                is_date_type = False
        # print(is_date_type)

        return is_date_type

    @staticmethod
    # 根据时间戳（到毫秒）获取uuid
    def get_uuid():
        return datetime.datetime.now().strftime('%Y%m%d%H%M%S%f')

    @staticmethod
    # 时间字符串转换为时间对象
    def string2time_stamp(str_value):

        try:
            d = datetime.datetime.strptime(str_value, "%Y-%m-%d %H:%M:%S.%f")
            t = d.timetuple()
            time_stamp = int(time.mktime(t))
            time_stamp = float(str(time_stamp) + str("%06d" % d.microsecond)) / 1000000
            return time_stamp
        except ValueError as e:
            print(e)
            d = datetime.datetime.strptime(str_value, "%Y-%m-%d %H:%M:%S")
            t = d.timetuple()
            time_stamp = int(time.mktime(t))
            time_stamp = float(str(time_stamp) + str("%06d" % d.microsecond)) / 1000000
            return time_stamp

    @staticmethod
    # 实践中字符串是否符合对应格式(YYYY-MM-DD HH:MM:SS)
    def check_time_format(time_str):
        pattern = re.compile(r'\d{4}-\d{1,2}-\d{1,2} \d{1,2}:\d{1,2}:\d{1,2}')
        if re.match(pattern, time_str):
            return True
        else:
            return False

    @staticmethod
    # 获取两个时间之间的相差天数
    # 时间格式为 "%Y-%m-%d %H:%M:%S"
    def compute_days_between_two_datetime(datetime_str1, datetime_str2):
        start_datetime = datetime.datetime.strptime(
            datetime_str1, "%Y-%m-%d %H:%M:%S")
        end_datetime = datetime.datetime.strptime(
            datetime_str2, "%Y-%m-%d %H:%M:%S")
        delta = abs(end_datetime - start_datetime)
        delta_days = delta.days
        return delta_days

    @staticmethod
    # 获取两个日期之间的相差天数
    # 日期格式为 "%Y-%m-%d"
    def compute_days_between_two_date(date_str1, date_str2):

        start_date = datetime.datetime.strptime(
            date_str1, "%Y-%m-%d")
        end_date = datetime.datetime.strptime(
            date_str2, "%Y-%m-%d")
        delta = abs(end_date - start_date)
        delta_days = delta.days
        return delta_days

    @staticmethod
    # 获取指定日期的前后几天的日期
    # delta_days 负数 为前几天
    # delta_days 正数 为后几天
    # 日期格式为 "%Y-%m-%d"
    def get_date_of_delta_days(date_str1, delta_days):
        base_date = datetime.datetime.strptime(
            date_str1, "%Y-%m-%d")
        need_date = base_date + timedelta(days=delta_days)
        return need_date.strftime("%Y-%m-%d")


if __name__ == '__main__':
    print(DateTimeHelper.compute_days_between_two_date("2023-12-1", "2023-12-6"))
    print(DateTimeHelper.compute_days_between_two_datetime("2023-12-1 0:0:0", "2023-12-6 15:34:36"))
    print(DateTimeHelper.get_date_of_delta_days("2023-12-1", 5))
    print(DateTimeHelper.get_date_of_delta_days("2023-12-1", -5))
    print(DateTimeHelper.parse_date("2023-12-1")[0])



"""
#!/usr/bin/python3.9
# -*- coding: utf-8 -*-
@Project :pythonCodeSnippet
@File    :cardTools.py
@IDE     :PyCharm
@Author  :chenxw
@Date    :2023/8/17 11:28
@Descr:  证件信息判断和提取
"""
import re
import datetime
from id_validator import validator
class CardHelper:
    def __init__(self):
        pass

    # 验证身份证号是否有效
    @staticmethod
    def is_valid_of_identity_card(identity_card):
        # 使用验证器验证身份证号
        result = validator.is_valid(identity_card)
        return result

    # 通过身份证号获取性别
    @staticmethod
    def get_sex_by_identity_card(identity_card):

        sex = identity_card[16:17]
        if int(sex) % 2:
            sex = '男'
        else:
            sex = '女'
        return sex

    # 通过身份证号获取出生日期
    @staticmethod
    def get_birthday_by_identity_card(identity_card):

        year = identity_card[6:10]
        month = identity_card[10:12]
        date = identity_card[12:14]
        birthy = year + '-' + month + '-' + date
        return birthy

    # 通过身份证号获取年龄（截止到现在）
    @staticmethod
    def get_age_by_identity_card(identity_card):
        birth_year = int(identity_card[6:10])
        birth_month = int(identity_card[10:12])
        birth_day = int(identity_card[12:14])
        birth_date = datetime.date(birth_year, birth_month, birth_day)
        age = datetime.date.today().year - birth_date.year
        return age

if __name__ == '__main__':
    print(CardHelper.is_valid_of_identity_card("510125197909282834"))
    print(CardHelper.is_valid_of_identity_card("130481198211102193"))
    print(CardHelper.is_valid_of_identity_card("532527198206251411"))
    print(CardHelper.is_valid_of_identity_card("65412819861118042X"))

    print(CardHelper.is_valid_of_identity_card("421003198812264015"))
    print(CardHelper.is_valid_of_identity_card("321081196505277533"))

    print(CardHelper.is_valid_of_identity_card("654121199601012799"))
    print(CardHelper.is_valid_of_identity_card("654223198102260919"))
    print(CardHelper.is_valid_of_identity_card("654124199012224012"))
    print(CardHelper.is_valid_of_identity_card("65410119901010117X"))
    print(CardHelper.is_valid_of_identity_card("632122199405171814"))

    print(CardHelper.is_valid_of_identity_card(str(211481196610250013)))
    print(CardHelper.is_valid_of_identity_card("330719197309044324"))
    print(CardHelper.is_valid_of_identity_card("211481197108100014"))
    print(CardHelper.is_valid_of_identity_card("330719197309044350"))






#!/usr/bin/python3.9
# -*- coding: utf-8 -*-
# @Time    :  2023/6/27 14:12
# @Author  : chenxw
# @Email   : gisfanmachel@gmail.com
# @File    : httpTools.py
# @Descr   : 
# @Software: PyCharm
class HttpHelper:
    # 初始化
    def __init__(self):
        pass


    @staticmethod
    # 获取http请求参数
    def get_params_request(request):
        params = ""
        dict_obj = None
        # POST请求
        if request.data is not None and len(request.data) != 0:
            dict_obj = request.data
        # GET请求
        elif request.query_params is not None and len(request.query_params) != 0:
            dict_obj = request.query_params
        if dict_obj is not None:
            for (k, v) in dict_obj.items():
                params = params + "{}={}".format(k, v) + "&"
        params = params.rstrip("&")

        return params

    @staticmethod
    # 获取ip地址
    def get_ip_request(request):
        if request.META.get('HTTP_X_FORWARDED_FOR'):
            ip = request.META.get("HTTP_X_FORWARDED_FOR")
        else:
            ip = request.META.get("REMOTE_ADDR")
        return ip


#!/usr/bin/python3.9
# -*- coding: utf-8 -*-
# @Time    : 2021/1/7 23:44
# @Author  : chenxw
# @Email   : gisfanmachel@gmail.com
# @File    : htmlParse.py
# @Desc    ：针对迭代器的一些操作
# @Software: PyCharm

from collections import Iterable


class IteratorHelper:
    # 初始化
    def __init__(self, iterator):
        self.iterator = iterator

    def get_iterator_count(self):
        flag = isinstance(self.iterator, Iterable)
        sum = 0
        if flag:
            for i in self.iterator:
                # print(i)
                if i is not None and str(i).strip() != "" and str(i).strip() != "\n":
                    sum = sum + 1
        return sum

    def is_has_value(self, check_array):
        flag = isinstance(self.iterator, Iterable)
        is_has = False
        if flag:
            for i in self.iterator:
                if i.text in check_array:
                    is_has = True
        return is_has



"""
===================================
#!/usr/bin/python3.9
# -*- coding: utf-8 -*-
@Author: chenxw
@Email : gisfanmachel@gmail.com
@File: fileTools.py
@Date: Create in 2021/1/28 12:23
@Description: 对文件的操作
@ Software: PyCharm
===================================
"""
import json
import os
import shutil
import zipfile

from vgis_aiutils.commonTools import CommonHelper


class FileHelper:
    # 初始化
    def __init__(self):
        pass

    # 根据路径创建文件夹
    # 可以创建下面的几级目录
    @staticmethod
    def mkdir(path):
        folder = os.path.exists(path)
        # 判断是否存在文件夹如果不存在则创建为文件夹
        if not folder:
            # 创建文件时如果路径不存在会创建这个路径
            os.makedirs(path)

    # 清空路径文件夹下所有文件
    @staticmethod
    def rmdir(img_dir):
        images = os.listdir(img_dir)
        for name in images:
            img_path = os.path.join(img_dir, name)
            os.remove(img_path)

    # 删除文件夹下的文件及子文件夹
    @staticmethod
    def rmDirAndFiles(file_dir):
        shutil.rmtree(file_dir)

    # 删除临时目录，包括其下面的文件
    @staticmethod
    def delete_tmp_dir(dir_path):
        common_utity = CommonHelper()
        for i in os.listdir(dir_path):
            file_data = dir_path + common_utity.get_dash_in_system()
            if os.path.isfile(file_data) is True:
                os.remove(file_data)
            else:
                FileHelper.delete_tmp_dir(file_data)

    # 删除文件
    @staticmethod
    def del_file(path):
        ls = os.listdir(path)
        for i in ls:
            c_path = os.path.join(path, i)
            if os.path.isdir(c_path):
                FileHelper.del_file(c_path)
            else:
                os.remove(c_path)


    # 得到文件的完整名称
    @staticmethod
    def get_file_name(orgin_file_path):
        (file_pre_path, temp_filename) = os.path.split(orgin_file_path)
        return temp_filename

    # 得到文件名称的前缀（只含名称）
    @staticmethod
    def get_file_name_prefix(orgin_file_path):
        (file_pre_path, temp_filename) = os.path.split(orgin_file_path)
        (shot_name, file_ext) = os.path.splitext(temp_filename)
        return shot_name

    # 得到文件名称的后缀
    @staticmethod
    def get_file_name_suffix(orgin_file_path):
        (file_pre_path, temp_filename) = os.path.split(orgin_file_path)
        (shot_name, file_ext) = os.path.splitext(temp_filename)
        return file_ext

    # 为文件增加副本，按照给出的后缀名
    @staticmethod
    def get_new_file_path_add_suffix(orgin_file_path, suffix_name):
        (file_pre_path, temp_filename) = os.path.split(orgin_file_path)
        (shot_name, file_ext) = os.path.splitext(temp_filename)
        common_utity = CommonHelper()
        bak_file_path = file_pre_path + common_utity.get_dash_in_system() + shot_name + "_" + suffix_name + file_ext
        return bak_file_path

    # 为文件名称增加后缀
    @staticmethod
    def add_subfix_on_file_name(file_dir_path, add_sub):
        file_names = os.listdir(file_dir_path)
        for temp in file_names:
            file = os.path.join(file_dir_path, temp)
            fname, ext = os.path.splitext(file)
            base_name = os.path.basename(fname)
            new_n = base_name + add_sub + ext
            os.rename(os.path.join(file_dir_path, temp), os.path.join(file_dir_path, new_n))

    # 在目标文件路径的同级目录下创建临时目录,并返回路径
    @staticmethod
    def make_tmp_dir_onside_file(dest_file_path):
        common_utity = CommonHelper()
        (file_pre_path, temp_filename) = os.path.split(dest_file_path)
        tmp_path = file_pre_path + common_utity.get_dash_in_system() + common_utity.get_uuid()
        # print("创建临时文件夹{}".format(tmp_path))
        os.makedirs(tmp_path)
        return tmp_path

    # 在目标文件路径下创建临时目录,并返回路径
    @staticmethod
    def make_tmp_dir_under_dir(dest_dir_path):
        common_utity = CommonHelper()
        tmp_path = dest_dir_path + common_utity.get_dash_in_system() + common_utity.get_uuid()
        # print("创建临时文件夹{}".format(tmp_path))
        os.makedirs(tmp_path)
        return tmp_path

    # 得到文件路径中的最后一级目录名
    @staticmethod
    def get_last_dir_name_in_file_path(orgin_file_path):
        (file_pre_path, temp_filename) = os.path.split(orgin_file_path)
        return FileHelper.get_last_dir_name_in_dir_path(file_pre_path)

    # 获取目录路径中的最后一级目录名
    @staticmethod
    def get_last_dir_name_in_dir_path(dir_path):
        common_utity = CommonHelper()
        last_dir_name = dir_path[dir_path.rindex(common_utity.get_dash_in_system()) + len(
            common_utity.get_dash_in_system()):]
        return last_dir_name

    # 得到文件路径中的完整目录路径
    @staticmethod
    def get_pre_path_in_file_path(orgin_file_path):
        (file_pre_path, temp_filename) = os.path.split(orgin_file_path)
        return file_pre_path

    # 查询文件夹下面是否有指定文件
    def is_has_file_in_dir(self, file_dir_path, file_name):
        is_find = False
        file_names = os.listdir(file_dir_path)
        for temp in file_names:
            if temp == file_name:
                is_find = True
                break
        return is_find

    # 清除文件内容
    # 主要针对文本文件类
    @staticmethod
    def clear_file_content(file_path):
        with open(file_path, "w") as file:
            file.truncate(0)

    @staticmethod
    # Copy指定格式的文件到新文件夹
    # 函数调用示例：SFileToDFile('d:\\quiz', '.txt', 'd:\\test')
    def sfile_to_dfile(sourcefile, fileclass, destinationfile):
        # 遍历目录和子目录
        for filenames in os.listdir(sourcefile):
            # 取得文件或文件名的绝对路径
            filepath = os.path.join(sourcefile, filenames)
            # 判断是否为文件夹
            if os.path.isdir(filepath):
                # 如果是文件夹，重新调用该函数
                FileHelper.sfile_to_dfile(filepath, fileclass, destinationfile)
            # 判断是否为文件
            elif os.path.isfile(filepath):
                # 如果该文件的后缀为用户指定的格式，则把该文件复制到用户指定的目录
                if filepath.endswith(fileclass):
                    # dirname = os.path.split(filepath)[-1]
                    # 给出提示信息
                    # print('Copy %s'% filepath +' To ' + destinationfile)
                    # print('Delet %s to recycle bin.' % filepath)
                    # # 删除文件
                    # send2trash.send2trash(filepath)
                    # 复制该文件到指定目录
                    shutil.copy(filepath, destinationfile)

    # 复制整个目录及子目录文件到指定文件夹
    # 指定可以忽略拷贝的文件ignore_patterns:.git
    @staticmethod
    def copy_allsubfiles(source_dir, target_dir, ignore_patterns):
        if ignore_patterns is not None:
            shutil.copytree(source_dir, target_dir, ignore=shutil.ignore_patterns(ignore_patterns))
        else:
            shutil.copytree(source_dir, target_dir)

    # 用于复制目录下本级所有文件到另一个目录
    @staticmethod
    def copy_allfiles(src, dest):
        src_files = os.listdir(src)
        # 创建输出目录
        FileHelper.mkdir(dest)

        for file_name in src_files:
            full_file_name = os.path.join(src, file_name)
            if os.path.isfile(full_file_name):
                shutil.copy(full_file_name, dest)

    # 复制文件到另外未知
    @staticmethod
    def copy_file(source_path, target_path):
        shutil.copyfile(source_path, target_path)


    # 创建zip文件
    @staticmethod
    def make_zip(source_dir, output_filename):
        zipf = zipfile.ZipFile(output_filename, 'w')
        pre_len = len(os.path.dirname(source_dir))
        for parent, dirnames, filenames in os.walk(source_dir):
            for filename in filenames:
                pathfile = os.path.join(parent, filename)
                arcname = pathfile[pre_len:].strip(os.path.sep)  # 相对路径
                zipf.write(pathfile, arcname)
        zipf.close()

    # 获取文件夹下指定后缀的文件
    # 比如图像文件后缀：suffix=['jpg', 'jpeg', 'JPG', 'JPEG', 'png', 'bmp']
    @staticmethod
    def get_file_list(file_dir, suffix):
        '''get all files path ends with suffix'''
        if not os.path.exists(file_dir):
            print("PATH:%s not exists" % file_dir)
            return []
        filelist = []
        for root, sdirs, files in os.walk(file_dir):
            if not files:
                continue
            for filename in files:
                filepath = os.path.join(root, filename)
                if filename.split('.')[-1] in suffix:
                    filelist.append(filepath)
        return filelist


class JsonHelper:
    def __init__(self):
        pass

    # 将json文件转成json对象
    @staticmethod
    def get_json_obj_by_file(json_file):
        with open(json_file, encoding="utf-8") as f:
            try:
                data = f.read()
                if data.startswith(u'\ufeff'):
                    data = data.encode('utf8')[3:].decode('utf8')
                json_obj = json.loads(data)
                return json_obj
            except Exception as exp:
                print(exp)
                print(exp.__traceback__.tb_frame.f_globals["__file__"])  # 发生异常所在的文件
                print(exp.__traceback__.tb_lineno)  # 发生异常所在的行数
                return None



#!/usr/bin/python3.9
# -*- coding: utf-8 -*-
# @Time    :  2023/6/27 14:18
# @Author  : chenxw
# @Email   : gisfanmachel@gmail.com
# @File    : stringTools.py
# @Descr   : 
# @Software: PyCharm
import re

import pypinyin


class StringHelper:
    def __int__(self):
        pass

    @staticmethod
    # 得到汉字的首拼音字母
    def get_pinyin(hanzi):
        a = pypinyin.pinyin(hanzi, style=pypinyin.FIRST_LETTER)
        b = []
        for i in range(len(a)):
            b.append(str(a[i][0]).upper())
        c = ''.join(b)
        return c

    @staticmethod
    # 获取字符串里的数字
    def get_number_in_str(input_str):
        return re.findall("\d+", input_str)

    @staticmethod
    # 获取字符串里的第一个数字
    def get_first_num_in_str(input_str):
        return re.findall("\d+", input_str)[0]

    # 获取字符串里的所有数字
    @staticmethod
    def get_complete_number_in_str(input_str):
        return re.findall('-?\d+.?\d+', input_str)

    @staticmethod
    # 获取字符串里的英文
    def get_en_in_str(input_str):
        en_str = re.sub("[\u4e00-\u9fa5\0-9\,\。]", "", input_str)
        return en_str

    @staticmethod
    # 检验字符串是否含有中文字符
    def is_contains_chinese(strs):
        for _char in strs:
            if '\u4e00' <= _char <= '\u9fa5':
                return True
        return False

    @staticmethod
    # 获取字符串里的中文
    def get_cn_in_str(input_str):
        str_result = re.findall("[\u4e00-\u9fa5]", input_str)
        str_return = ""
        for one in str_result:
            str_return = str_return + one
        return str_return

    # 获取两个字符串中间的字符串
    @staticmethod
    def get_str_btw(s, f, b):
        par = s.partition(f)
        return (par[2].partition(b))[0][:]

    @staticmethod
    # 将字符串里的中文转为首写拼音
    def convert_hanzi_to_pinyin_in_str(input_str):
        str_result = re.findall("[\u4e00-\u9fa5]", input_str)
        str_return = ""
        replace_list = []
        for hanzi in str_result:
            pinyin = StringHelper.get_pinyin(hanzi)
            replace_list.append({"hanzi": hanzi, "pinyin": pinyin})
        for replace in replace_list:
            input_str = input_str.replace(replace.get("hanzi"), replace.get("pinyin"))
        if len(re.findall("[\u4e00-\u9fa5]", input_str)) == 0:
            return input_str
        else:
            StringHelper.convert_hanzi_to_pinyin_in_str(input_str)

    @staticmethod
    # 去掉字符串里的\x开头的特殊字符
    def handle_x_str(content):
        # 使用unicode-escape编码集，将unicode内存编码值直接存储
        content = content.encode('unicode_escape').decode('utf-8')
        # 利用正则匹配\x开头的特殊字符
        result = re.findall(r'\\x[a-f0-9]{2}', content)
        for x in result:
            # 替换找的的特殊字符
            content = content.replace(x, '')
        # 最后再解码
        content = content.encode('utf-8').decode('unicode_escape')
        return content

    @staticmethod
    # 首字母小写
    def decapitalize(string):
        return string[:1].lower() + string[1:]

    @staticmethod
    # 获取字符串里按照指定字符开始的指定长度的子字符串
    def get_sub_str_by_startstr_of_length(input_str, start_str, sub_length):
        return_str = input_str[input_str.index(start_str): input_str.index(start_str)+sub_length]
        return return_str


if __name__ == '__main__':
    input_str = "中故宫eee中工"
    # input_str = StringHelper.convert_hanzi_to_pinyin_in_str(input_str)
    # # 纯文本
    # #     # 预期运行寿命：5年 ; ≤1.25年
    # #     # 推进剂:86kg ; ≤26kg
    # #     # 码率：高于1×10-5 ; ≤1×10-6 ; 1×10-6 ; 双通道均＞1×10-6
    # #     # 三轴指向精度<0.1(3)  ; ≥0.5°(3)
    # #     # 成像期间光轴指向精度：≤ 0.01o (三轴，3σ)
    # #     # 稳定度：≥310-2/s(3) ; ≥0.01°/S(3)
    # #     # **输出功率：3000W，≤1800W ; >2450W ; ≥320W
    # #     # 蓄电池结构块:8个 ;  ≤4个
    # #     # 蓄电池组容量：≤10Ah ; 60Ah
    # #     # 每日地面站获取图像最大能力:每日均≥450景（每日14轨） ; 任意一日＜90景
    # #     # X波段数传EIRP：≥28dBW ; ≤25dBW（主备均失效）
    # #     # 存储容量: ≥8Tbits(主+备) ; 0 bit
    # #     # 相机单轨可成像时间:≧10min ; ≤6min
    # #     # 相机全色像元数:12288像元×3片 ; ≤18432 ; 3072像元/谱段×3片 ; ≤4608
    # #     # 分辨率：2 ; ≥4
    # #     # 最大信噪比：≥ 48dB ; ≤23dB ; ≥48 ; ≤24
    # #     # SAR载荷工作模式:3种（滑动聚束、条带、宽幅） ; 失效两种或以上工作模式
    # #     # 后向散射系数:分辨率1~10m, 成像边缘优于-19dB；分辨率25~500m, 成像中心优于-25dB，边缘优于-21dB像 ; 比设计指标恶化3dB
    # #     # 后向散射系数：-23dB~-20dB ; ≥-17dB
    # #     # SAR（通道数：1536）:超过307个通道失效
    # #     # 水色水温扫描仪:≤0.20K(300K时NEΔT)
    # #     # AIS分系统:1天之内收不到报文数据 ; 在24小时内不能收到报文数据 ; 1天内收到的船舶报文总数小于25000条
    # #     # 接收机灵敏度：优于-111dBm ; ≥-103.7dBm
    # #     # 微波散射计: 1） 发射功率低于失效值  2） 内定标值低于失效值  3） 头部不能转动 上述3个条件中有一个满足，分系统失效
    # #     # 校正辐射计:2通道失效 ; 2 ; 1
    # #     # 雷达高度计:Ku或C通道失效 ; 1
    # #     # 空间环境探测器：超过288个子通道的探测精度≥100% ; ≤10% ; 长时间(大于180天)无探测或数值无变化 ; 1 nt ;  超过12个子通道的探测精度≥ 10 nt
    # #     # 风场测量雷达：≥1.0/2.0dB （刈幅远端，风速≥5m/s / 风速=3m/s）
    # #     # 气溶胶探测仪：9个通道中5个以上通道失效  头部扫描镜不能转动  上述2个条件中有一个满足，该载荷失效 4个通道中2个以上通道失效，该载荷失效
    # #     # 中能粒子载荷：输出为1 ; 输出为0 ; 2.4±0.5V ; ＜1.2V ; 0.2~0.3A
    # #     # 磁力仪：（1）VFM矢量磁力仪单元传感器无法正常加电工作；和/或 （2）VFM矢量磁力仪单元电子学箱主备份均无法正常加电和/或无法输出数据。
    # #     # (1) ASC高精度星敏感器单元3个镜头单元均无法正常加电；和/或 (2) ASC高精度星敏感器单元高精度星敏感器电子学箱无法正常加电工作
    # input_str = "2.4±0.5V"
    # input_str = StringHelper.get_complete_number_in_str(input_str)
    # print(input_str)
    print(StringHelper.get_sub_str_by_startstr_of_length(input_str, "eee", 4))



"""
#!/usr/bin/python3.9
# -*- coding: utf-8 -*-
@Project :pythonCodeSnippet
@File    :numberTools.py
@IDE     :PyCharm
@Author  :chenxw
@Date    :2023/8/30 11:47
@Descr:
"""
import cn2an


class NumberHelper:
    def __int__(self):
        pass

    # 将阿拉伯数字转换为中文数字（小写，大写，人民币）
    # mode:lower,up,rmb
    @staticmethod
    def convert_alabic_number_to_chinese_number(alabic_number, mode):
        return cn2an.an2cn(alabic_number, mode)

    # 将中文数字（小写，大写）转为阿拉伯数字
    # mode:lower,up,rmb
    @staticmethod
    def convert_chinese_number_to_alabic_number(chinese_number):
        return cn2an.an2cn(chinese_number)


# -*- coding: utf-8 -*-
import os

import cv2  ##加载OpenCV模块


class VideoOperator:
    def __init__(self):
        pass

    # 视频转图片
    def video2frames(self, pathIn='',
                     pathOut='',
                     only_output_video_info=False,
                     extract_time_points=None,
                     initial_extract_time=0,
                     end_extract_time=None,
                     extract_time_interval=-1,
                     output_prefix='frame',
                     jpg_quality=100,
                     isColor=True):
        '''
        pathIn：视频的路径，比如：F:\python_tutorials\test.mp4
        pathOut：设定提取的图片保存在哪个文件夹下，比如：F:\python_tutorials\frames1\。如果该文件夹不存在，函数将自动创建它
        only_output_video_info：如果为True，只输出视频信息（长度、帧数和帧率），不提取图片
        extract_time_points：提取的时间点，单位为秒，为元组数据，比如，(2, 3, 5)表示只提取视频第2秒， 第3秒，第5秒图片
        initial_extract_time：提取的起始时刻，单位为秒，默认为0（即从视频最开始提取）
        end_extract_time：提取的终止时刻，单位为秒，默认为None（即视频终点）
        extract_time_interval：提取的时间间隔，单位为秒，默认为-1（即输出时间范围内的所有帧）
        output_prefix：图片的前缀名，默认为frame，图片的名称将为frame_000001.jpg、frame_000002.jpg、frame_000003.jpg......
        jpg_quality：设置图片质量，范围为0到100，默认为100（质量最佳）
        isColor：如果为False，输出的将是黑白图片
        '''

        cap = cv2.VideoCapture(pathIn)  ##打开视频文件
        n_frames = int(cap.get(cv2.CAP_PROP_FRAME_COUNT))  ##视频的帧数
        fps = cap.get(cv2.CAP_PROP_FPS)  ##视频的帧率
        dur = n_frames / fps  ##视频的时间

        ##如果only_output_video_info=True, 只输出视频信息，不提取图片
        if only_output_video_info:
            print('only output the vgis_video information (without extract frames)::::::')
            print("Duration of the vgis_video: {} seconds".format(dur))
            print("Number of frames: {}".format(n_frames))
            print("Frames per second (FPS): {}".format(fps))

            ##提取特定时间点图片
        elif extract_time_points is not None:
            if max(extract_time_points) > dur:  ##判断时间点是否符合要求
                raise NameError('the max vgis_datetime point is larger than the vgis_video duration....')
            try:
                os.mkdir(pathOut)
            except OSError:
                pass
            success = True
            count = 0
            while success and count < len(extract_time_points):
                cap.set(cv2.CAP_PROP_POS_MSEC, (1000 * extract_time_points[count]))
                success, image = cap.read()
                if success:
                    if not isColor:
                        image = cv2.cvtColor(image, cv2.COLOR_BGR2GRAY)  ##转化为黑白图片
                    print('Write a new frame: {}, {}th'.format(success, count + 1))
                    cv2.imwrite(os.path.join(pathOut, "{}_{:06d}.jpg".format(output_prefix, count + 1)), image,
                                [int(cv2.IMWRITE_JPEG_QUALITY), jpg_quality])  # save frame as JPEG vgis_file
                    count = count + 1

        else:
            ##判断起始时间、终止时间参数是否符合要求
            if initial_extract_time > dur:
                raise NameError('initial extract vgis_datetime is larger than the vgis_video duration....')
            if end_extract_time is not None:
                if end_extract_time > dur:
                    raise NameError('end extract vgis_datetime is larger than the vgis_video duration....')
                if initial_extract_time > end_extract_time:
                    raise NameError('end extract vgis_datetime is less than the initial extract vgis_datetime....')

            ##时间范围内的每帧图片都输出
            if extract_time_interval == -1:
                if initial_extract_time > 0:
                    cap.set(cv2.CAP_PROP_POS_MSEC, (1000 * initial_extract_time))
                try:
                    os.mkdir(pathOut)
                except OSError:
                    pass
                print('Converting a vgis_video into frames......')
                if end_extract_time is not None:
                    N = (end_extract_time - initial_extract_time) * fps + 1
                    success = True
                    count = 0
                    while success and count < N:
                        success, image = cap.read()
                        if success:
                            if not isColor:
                                image = cv2.cvtColor(image, cv2.COLOR_BGR2GRAY)
                            print('Write a new frame: {}, {}/{}'.format(success, count + 1, n_frames))
                            cv2.imwrite(os.path.join(pathOut, "{}_{:06d}.jpg".format(output_prefix, count + 1)), image,
                                        [int(cv2.IMWRITE_JPEG_QUALITY), jpg_quality])  # save frame as JPEG vgis_file
                            count = count + 1
                else:
                    success = True
                    count = 0
                    while success:
                        success, image = cap.read()
                        if success:
                            if not isColor:
                                image = cv2.cvtColor(image, cv2.COLOR_BGR2GRAY)
                            print('Write a new frame: {}, {}/{}'.format(success, count + 1, n_frames))
                            cv2.imwrite(os.path.join(pathOut, "{}_{:06d}.jpg".format(output_prefix, count + 1)), image,
                                        [int(cv2.IMWRITE_JPEG_QUALITY), jpg_quality])  # save frame as JPEG vgis_file
                            count = count + 1

            ##判断提取时间间隔设置是否符合要求
            elif extract_time_interval > 0 and extract_time_interval < 1 / fps:
                raise NameError('extract_time_interval is less than the frame vgis_datetime interval....')
            elif extract_time_interval > (n_frames / fps):
                raise NameError('extract_time_interval is larger than the duration of the vgis_video....')

            ##时间范围内每隔一段时间输出一张图片
            else:
                try:
                    os.mkdir(pathOut)
                except OSError:
                    pass
                print('Converting a vgis_video into frames......')
                if end_extract_time is not None:
                    N = (end_extract_time - initial_extract_time) / extract_time_interval + 1
                    success = True
                    count = 0
                    while success and count < N:
                        cap.set(cv2.CAP_PROP_POS_MSEC,
                                (1000 * initial_extract_time + count * 1000 * extract_time_interval))
                        success, image = cap.read()
                        if success:
                            if not isColor:
                                image = cv2.cvtColor(image, cv2.COLOR_BGR2GRAY)
                            print('Write a new frame: {}, {}th'.format(success, count + 1))
                            cv2.imwrite(os.path.join(pathOut, "{}_{:06d}.jpg".format(output_prefix, count + 1)), image,
                                        [int(cv2.IMWRITE_JPEG_QUALITY), jpg_quality])  # save frame as JPEG vgis_file
                            count = count + 1
                else:
                    success = True
                    count = 0
                    while success:
                        cap.set(cv2.CAP_PROP_POS_MSEC,
                                (1000 * initial_extract_time + count * 1000 * extract_time_interval))
                        success, image = cap.read()
                        if success:
                            if not isColor:
                                image = cv2.cvtColor(image, cv2.COLOR_BGR2GRAY)
                            print('Write a new frame: {}, {}th'.format(success, count + 1))
                            cv2.imwrite(os.path.join(pathOut, "{}_{:06d}.jpg".format(output_prefix, count + 1)), image,
                                        [int(cv2.IMWRITE_JPEG_QUALITY), jpg_quality])  # save frame as JPEG vgis_file
                            count = count + 1


def convert_video_to_images_test(video_operator):
    ##### 测试
    pathIn = 'D:\\vgis_video\\test.mp4'
    video_operator.video2frames(pathIn, only_output_video_info=True)

    pathOut = 'D:\\vgis_video\\frames1'
    video_operator.video2frames(pathIn, pathOut)
    #
    # pathOut = 'D:\\资料\\frames2'
    # 只提取了第1秒，第2秒和第5秒图片
    # video_operator.video2frames(pathIn, pathOut, extract_time_points=(1, 2, 5))
    #
    # pathOut = 'D:\\资料\\frames3'
    # 可以看到，1到3秒内的视频每隔0.5秒提取图片，共5张图片（分别为1s, 1.5s, 2s, 2.5s, 3s时刻的图片）
    # video_operator.video2frames(pathIn, pathOut,
    #              initial_extract_time=1,
    #              end_extract_time=3,
    #              extract_time_interval=0.5)
    #
    # pathOut = 'D:\\资料\\frames4'
    # video_operator.video2frames(pathIn, pathOut, extract_time_points=(0.3, 2), isColor=False)
    #
    # pathOut = 'D:\\资料\\frames5'
    # video_operator.video2frames(pathIn, pathOut, extract_time_points=(0.3, 2), jpg_quality=50)


# 主入口,进行测试
if __name__ == '__main__':
    try:
        video_operator = VideoOperator()

        convert_video_to_images_test(video_operator)

    except Exception as tm_exp:
        print("测试用例失败：{}".format(str(tm_exp)))



#!/usr/bin/python3.9
# -*- coding: utf-8 -*-
# @Time    :  2023/6/27 14:21
# @Author  : chenxw
# @Email   : gisfanmachel@gmail.com
# @File    : moneyTools.py
# @Descr   : 
# @Software: PyCharm
import re

import requests

from vgis_aiutils.vgis_string.stringTools import StringHelper


class MoneyHelper:
    def __int__(self):
        pass

    @staticmethod
    # 获取货币的符号、数值等信息
    # 133,988,250 USD 转为 133988250 USD end
    # $1,531,180.00 转换为 1531180.00 $  head
    # 目前考虑三种货币 美元USB   $ 人民币  CNY ¥  欧元EUR  €
    def parse_currency(currency_text):
        currency_unit = None
        currency_value = None
        unit_position = None
        if currency_text is not None and str(currency_text).strip() != "":
            # 获取货币文本里的金额数值
            currency_value = currency_text.upper().replace(",", "").replace(" ", "")
            # currency_value = currency_value.lstrip("$").lstrip("$").lstrip("$")
            # currency_value = currency_value.rstrip("USD").rstrip("CNY").rstrip("EUR")
            currency_value = re.sub(r'[^0-9.]', '', currency_value)

            # 获取货币文本里的币种单位
            currency_value2 = currency_text.upper().replace(",", "").replace(" ", "").replace(".", "")
            is_head_unit = False
            is_end_unit = False
            if len(currency_value2) > 0:
                if not currency_value2[0].isdigit():
                    is_head_unit = True
                if not currency_value2[len(currency_value2) - 1].isdigit():
                    is_end_unit = True
            head_unit = None
            end_unit = None
            if is_head_unit:
                head_unit = ""
                for s in currency_value2:
                    if not s.isdigit():
                        head_unit += s
                    else:
                        break
            if is_end_unit:
                end_unit = ""
                for s in currency_value2:
                    if s.isdigit():
                        continue
                    else:
                        end_unit += s
            currency_unit = head_unit if head_unit is not None else end_unit
            unit_position = "head" if is_head_unit else "end" if is_end_unit else None
        # print(currency_value)
        # print(currency_unit)
        # print(unit_position)
        return currency_value, currency_unit, unit_position

    @staticmethod
    # 将会计财务专用格式转换为数值
    # 1,531,180.00,转为1531180.00
    def deecimal_currency(currency_value):
        # 获取货币文本里的金额数值
        currency_value = currency_value.upper().replace(",", "").replace(" ", "")
        currency_value = re.sub(r'[^0-9.]', '', currency_value)
        # print(currency_value)
        return currency_value

    @staticmethod
    # 将货币数值转换为会计财务专用表达方式
    # 1531180.00 转换为 1,531,180.00
    def thousand_sep_currency(currency_value):
        if currency_value is not None and str(currency_value) != "" and "," not in str(currency_value):
            currency_value = "{:,}".format(float(currency_value))
            # print(currency_value)
        else:
            currency_value = ""
        return currency_value

    @staticmethod
    # 将货币数值转换为会计财务专用表达方式，并增加币种单位
    # 1531180.00 转换为 1,531,180.00
    def thousand_sep_currency_add_unit(currency_value, currency_unit, unit_position):
        if currency_value is not None and str(currency_value) != "" and "," not in str(currency_value):
            currency_value = "{:,}".format(float(currency_value))
            # print(currency_value)
        else:
            currency_value = ""
        if unit_position is not None:
            if unit_position == "head":
                currency_value = currency_unit + currency_value
            if unit_position == "end":
                currency_value = currency_value + " " + currency_unit
        # print(currency_value)
        return currency_value

    @staticmethod
    # 根据币种中文获取币种英文
    def getCurrencyUnitByCname(currencyUnitCname):
        currencyUnit = "USD,$"
        for unit in ["人民币,CNY,¥", "美元,USD,$", "欧元,EUR,€"]:
            if currencyUnitCname == unit.split(",")[0]:
                currencyUnit = unit.split(",")[1] + "," + unit.split(",")[2]
        return currencyUnit

    @staticmethod
    def get_end_position_curreny_unit(current_unit):
        currencyUnit = "USB"
        if StringHelper.is_contains_chinese(current_unit):
            currencyUnit = MoneyHelper.getCurrencyUnitByCname(current_unit)[0]
        else:
            if len(current_unit) == 0:
                for unit in ["人民币,CNY,¥", "美元,USD,$", "欧元,EUR,€"]:
                    if current_unit == unit.split(",")[2]:
                        currencyUnit = unit.split(",")[1]
        return currencyUnit

    @staticmethod
    # USD 10, 714,018 这种不合规范的转换位置  为10,714,018 USD
    def changeCurrencyUnitPostion(currencyStr):
        currencyStrReturn = currencyStr
        currencyEn = StringHelper.get_en_in_str(currencyStr)
        if currencyStr.find(currencyEn) == 0:
            currencyStrReturn = currencyStr.lstrip(currencyEn) + " " + currencyEn
        return currencyStrReturn

    @staticmethod
    # 根据币种获取币种位置
    def getCurrencyUnitPositionByUnit(currencyUnit):
        if StringHelper.is_contains_chinese(currencyUnit):
            currencyUnit = MoneyHelper.getCurrencyUnitByCname(currencyUnit)[0]
        position = "head"
        if len(currencyUnit) == 3:
            position = "end"
        return position

    @staticmethod
    # 实时汇率转换(其他币种转换未美元)
    def getConvertAmount(from_currency, to_currency, amount):
        convert_amount = 0.0
        url = 'https://api.exchangerate-api.com/v4/latest/USD'
        converter = RealTimeCurrencyConverter(url)
        # (converter.convert('CNY','USD',100))
        convert_amount = converter.convert(from_currency, to_currency, amount)
        return convert_amount

    # 相对于美元的转换汇率
    @staticmethod
    def getConvertRateByBaseUSD(from_currency):
        url = 'https://api.exchangerate-api.com/v4/latest/USD'
        converter = RealTimeCurrencyConverter(url)
        convert_rate = converter.get_rate(from_currency)
        return convert_rate



    @staticmethod
    # 获取货币的符号、数值等信息
    # 133,988,250 USD 转为 133988250 USD end
    # $1,531,180.00 转换为 1531180.00 $  head
    # 目前考虑三种货币 美元USB   $ 人民币  CNY ¥  欧元EUR  €
    def parse_currency(currency_text):
        currency_unit = None
        currency_value = None
        unit_position = None
        if currency_text is not None and str(currency_text).strip() != "":
            # 获取货币文本里的金额数值
            currency_value = currency_text.upper().replace(",", "").replace(" ", "")
            # currency_value = currency_value.lstrip("$").lstrip("$").lstrip("$")
            # currency_value = currency_value.rstrip("USD").rstrip("CNY").rstrip("EUR")
            currency_value = re.sub(r'[^0-9.]', '', currency_value)

            # 获取货币文本里的币种单位
            currency_value2 = currency_text.upper().replace(",", "").replace(" ", "").replace(".", "")
            is_head_unit = False
            is_end_unit = False
            if len(currency_value2) > 0:
                if not currency_value2[0].isdigit():
                    is_head_unit = True
                if not currency_value2[len(currency_value2) - 1].isdigit():
                    is_end_unit = True
            head_unit = None
            end_unit = None
            if is_head_unit:
                head_unit = ""
                for s in currency_value2:
                    if not s.isdigit():
                        head_unit += s
                    else:
                        break
            if is_end_unit:
                end_unit = ""
                for s in currency_value2:
                    if s.isdigit():
                        continue
                    else:
                        end_unit += s
            currency_unit = head_unit if head_unit is not None else end_unit
            unit_position = "head" if is_head_unit else "end" if is_end_unit else None
        # print(currency_value)
        # print(currency_unit)
        # print(unit_position)
        return currency_value, currency_unit, unit_position

    @staticmethod
    # 将会计财务专用格式转换为数值
    # 1,531,180.00,转为1531180.00
    def deecimal_currency(currency_value):
        # 获取货币文本里的金额数值
        currency_value = currency_value.upper().replace(",", "").replace(" ", "")
        currency_value = re.sub(r'[^0-9.]', '', currency_value)
        # print(currency_value)
        return currency_value

    @staticmethod
    # 将货币数值转换为会计财务专用表达方式
    # 1531180.00 转换为 1,531,180.00
    def thousand_sep_currency(currency_value):
        if currency_value is not None and str(currency_value) != "" and "," not in str(currency_value):
            currency_value = "{:,}".format(float(currency_value))
            # print(currency_value)
        else:
            currency_value = ""
        return currency_value

    @staticmethod
    # 将货币数值转换为会计财务专用表达方式，并增加币种单位
    # 1531180.00 转换为 1,531,180.00
    def thousand_sep_currency_add_unit(currency_value, currency_unit, unit_position):
        if currency_value is not None and str(currency_value) != "" and "," not in str(currency_value):
            currency_value = "{:,}".format(float(currency_value))
            # print(currency_value)
        else:
            currency_value = ""
        if unit_position is not None:
            if unit_position == "head":
                currency_value = currency_unit + currency_value
            if unit_position == "end":
                currency_value = currency_value + " " + currency_unit
        # print(currency_value)
        return currency_value

    @staticmethod
    # 根据币种中文获取币种英文
    def getCurrencyUnitByCname(currencyUnitCname):
        currencyUnit = "USD,$"
        for unit in ["人民币,CNY,¥", "美元,USD,$", "欧元,EUR,€"]:
            if currencyUnitCname == unit.split(",")[0]:
                currencyUnit = unit.split(",")[1] + "," + unit.split(",")[2]
        return currencyUnit

    @staticmethod
    def get_end_position_curreny_unit(current_unit):
        currencyUnit = "USB"
        if StringHelper.is_contains_chinese(current_unit):
            currencyUnit = MoneyHelper.getCurrencyUnitByCname(current_unit)[0]
        else:
            if len(current_unit) == 0:
                for unit in ["人民币,CNY,¥", "美元,USD,$", "欧元,EUR,€"]:
                    if current_unit == unit.split(",")[2]:
                        currencyUnit = unit.split(",")[1]
        return currencyUnit

    @staticmethod
    # USD 10, 714,018 这种不合规范的转换位置  为10,714,018 USD
    def changeCurrencyUnitPostion(currencyStr):
        currencyStrReturn = currencyStr
        currencyEn = StringHelper.get_en_in_str(currencyStr)
        if currencyStr.find(currencyEn) == 0:
            currencyStrReturn = currencyStr.lstrip(currencyEn) + " " + currencyEn
        return currencyStrReturn

    @staticmethod
    # 根据币种获取币种位置
    def getCurrencyUnitPositionByUnit(currencyUnit):
        if StringHelper.is_contains_chinese(currencyUnit):
            currencyUnit = MoneyHelper.getCurrencyUnitByCname(currencyUnit)[0]
        position = "head"
        if len(currencyUnit) == 3:
            position = "end"
        return position

    @staticmethod
    # 实时汇率转换(其他币种转换未美元)
    def getConvertAmount(from_currency, to_currency, amount):
        convert_amount = 0.0
        url = 'https://api.exchangerate-api.com/v4/latest/USD'
        converter = RealTimeCurrencyConverter(url)
        # (converter.convert('CNY','USD',100))
        convert_amount = converter.convert(from_currency, to_currency, amount)
        return convert_amount


    # 相对于美元的转换汇率
    @staticmethod
    def getConvertRateByBaseUSD(from_currency):
        url = 'https://api.exchangerate-api.com/v4/latest/USD'
        converter = RealTimeCurrencyConverter(url)
        convert_rate = converter.get_rate(from_currency)
        return convert_rate

class RealTimeCurrencyConverter():
    def __init__(self, url):
        self.data = requests.get(url).json()
        self.currencies = self.data['rates']

    def convert(self, from_currency, to_currency, amount):
        initial_amount = amount
        if from_currency != 'USD':
            amount = amount / self.currencies[from_currency]

            # limiting the precision to 4 decimal places
        amount = round(amount * self.currencies[to_currency], 4)
        return amount

    def get_rate(self, from_currency):
        rate = 1.0
        if from_currency != 'USD':
            rate = self.currencies[from_currency]
        return rate


#!/usr/bin/python3.9
# -*- coding: utf-8 -*-
# @Time    : 2021/1/8 9:52
# @Author  : chenxw
# @Email   : gisfanmache.@gmail.com
# @File    : commonTools.py
# @Descr   : 通用工具类
# @Software: PyCharm
import platform
import subprocess


class CommonHelper:
    # 初始化
    def __init__(self):
        pass

    @staticmethod
    # 获取换行符
    def get_line_feed():
        if platform.system() == 'Windows':
            return "\n"
        else:
            return "\n"

    @staticmethod
    # 得到文件路径的斜杆写法
    # 也可以直接用os.sep
    def get_dash_in_system():
        if platform.system() == 'Windows':
            return "\\"
        else:
            return "/"


    @staticmethod
    # 执行cmd命令
    def run_command( cmd_str):
        out = subprocess.Popen(cmd_str, shell=True)



    @staticmethod
    # 转换布尔值为中文
    def convert_to_boolean_evalue(boolean_cvalue):
        boolean_evalue = True
        if boolean_cvalue == "否" or boolean_cvalue == False:
            boolean_evalue = False
        return boolean_evalue

    @staticmethod
    # 转换布尔值为英文
    def convert_to_boolean_cvalue(boolean_evalue):
        boolean_cvalue = "是"
        if boolean_evalue == False or boolean_evalue == "否":
            boolean_cvalue = "否"
        return boolean_cvalue





